@@ -76,6 +76,6 @@ class JiraSmartCz(BaseCommitizen):
     def info(self) -> str:
         dir_path = os.path.dirname(os.path.realpath(__file__))
         filepath = os.path.join(dir_path, "jira_info.txt")
-        with open(filepath, "r") as f:
+        with open(filepath, "r", encoding=self.config.settings["encoding"]) as f:
             content = f.read()
         return content
