@@ -1,7 +1,12 @@
+import io
 import sys
 
 from termcolor import colored
 
+if sys.platform == "win32":
+    if isinstance(sys.stdout, io.TextIOWrapper) and sys.version_info >= (3, 7):
+        sys.stdout.reconfigure(encoding="utf-8")
+
 
 def write(value: str, *args) -> None:
     """Intended to be used when value is multiline."""
